@@ -1,7 +1,7 @@
 """
 Type annotations for ebs service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/literals/)
 
 Usage::
 
@@ -19,12 +19,21 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("ChecksumAggregationMethodType", "ChecksumAlgorithmType", "StatusType", "ServiceName")
+__all__ = (
+    "ChecksumAggregationMethodType",
+    "ChecksumAlgorithmType",
+    "StatusType",
+    "EBSServiceName",
+    "ServiceName",
+    "ResourceServiceName",
+    "RegionName",
+)
 
 
 ChecksumAggregationMethodType = Literal["LINEAR"]
 ChecksumAlgorithmType = Literal["SHA256"]
 StatusType = Literal["completed", "error", "pending"]
+EBSServiceName = Literal["ebs"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -58,6 +67,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -312,3 +322,38 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
+RegionName = Literal[
+    "af-south-1",
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
