@@ -1,7 +1,7 @@
 """
 Type annotations for ebs service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/type_defs/)
 
 Usage::
 
@@ -16,6 +16,7 @@ from datetime import datetime
 from typing import IO, Dict, List, Sequence, Union
 
 from botocore.response import StreamingBody
+from typing_extensions import NotRequired
 
 from .literals import StatusType
 
